@@ -1,3 +1,4 @@
+"""Pre Cookie Hook: Templated File with jinja2 syntax"""
 import json
 import logging
 import sys
@@ -19,6 +20,7 @@ def get_request():
     interpreters = cookiecutter['interpreters']
     if isinstance(interpreters, str):  # we assume it is json
         interpreters = json.loads(interpreters)
+        cookiecutter['interpreters'] = interpreters
     # the name the client code should use to import the generated package/module
     module_name = '{{ cookiecutter.pkg_name }}'
 
